@@ -41,7 +41,6 @@ require_once dirname(__FILE__).'/users.inc.php';
 function getSystemStatusData(array $filter) {
 	$filter_groupids = (array_key_exists('groupids', $filter) && $filter['groupids']) ? $filter['groupids'] : null;
 	$filter_hostids = (array_key_exists('hostids', $filter) && $filter['hostids']) ? $filter['hostids'] : null;
-	$filter_triggerids = null;
 	$filter_severities = (array_key_exists('severities', $filter) && $filter['severities'])
 		? $filter['severities']
 		: range(TRIGGER_SEVERITY_NOT_CLASSIFIED, TRIGGER_SEVERITY_COUNT - 1);
@@ -79,19 +78,6 @@ function getSystemStatusData(array $filter) {
 		$filter_hostids = array_diff($filter_hostids, $exclude_hostids);
 	}
 
-	if (array_key_exists('problem', $filter) && $filter['problem'] !== '') {
-		$filter_triggerids = array_keys(API::Trigger()->get([
-			'output' => [],
-			'groupids' => $filter_groupids,
-			'hostids' => $filter_hostids,
-			'search' => ['description' => $filter['problem']],
-			'preservekeys' => true
-		]));
-
-		$filter_groupids = null;
-		$filter_hostids = null;
-	}
-
 	$data = [
 		'groups' => API::HostGroup()->get([
 			'output' => ['groupid', 'name'],
@@ -126,12 +112,12 @@ function getSystemStatusData(array $filter) {
 		'hostids' => $filter_hostids,
 		'source' => EVENT_SOURCE_TRIGGERS,
 		'object' => EVENT_OBJECT_TRIGGER,
-		'objectids' => $filter_triggerids,
 		'suppressed' => false,
 		'sortfield' => ['eventid'],
 		'sortorder' => ZBX_SORT_DOWN,
 		'preservekeys' => true
 	];
+
 	if (array_key_exists('severities', $filter)) {
 		$filter_severities = implode(',', $filter['severities']);
 		$all_severities = implode(',', range(TRIGGER_SEVERITY_NOT_CLASSIFIED, TRIGGER_SEVERITY_COUNT - 1));
@@ -140,16 +126,21 @@ function getSystemStatusData(array $filter) {
 			$options['severities'] = $filter['severities'];
 		}
 	}
+
 	if (array_key_exists('show_suppressed', $filter) && $filter['show_suppressed']) {
 		unset($options['suppressed']);
 		$options['selectSuppressionData'] = ['maintenanceid', 'suppress_until'];
 	}
+
 	if ($filter_ext_ack == EXTACK_OPTION_UNACK) {
 		$options['acknowledged'] = false;
 	}
 
-	$problems = API::Problem()->get($options);
+	if (array_key_exists('problem', $filter) && $filter['problem'] !== '') {
+		$options['search'] = ['name' => $filter['problem']];
+	}
 
+	$problems = API::Problem()->get($options);
 	if ($problems) {
 		$triggerids = [];
 
