@@ -769,6 +769,10 @@ class CSvgGraph extends CSvg {
 	 * Calculate paths for metric elements.
 	 */
 	protected function calculatePaths() {
+		// Metric having very big values of y outside visible area will fail to render.
+		$y_max = pow(2, 16);
+		$y_min = $y_max * -1;
+
 		foreach ($this->metrics as $index => $metric) {
 			if (!array_key_exists($index, $this->points)) {
 				continue;
@@ -783,8 +787,8 @@ class CSvgGraph extends CSvg {
 				$max_value = $this->left_y_max;
 			}
 
-			$time_range = $this->time_till - $this->time_from ? : 1;
-			$value_diff = $max_value - $min_value ? : 1;
+			$time_range = ($this->time_till - $this->time_from) ? : 1;
+			$value_diff = ($max_value - $min_value) ? : 1;
 			$timeshift = $metric['options']['timeshift'];
 			$paths = [];
 
@@ -805,6 +809,11 @@ class CSvgGraph extends CSvg {
 					$x = $this->canvas_x + $this->canvas_width
 						- $this->canvas_width * ($this->time_till - $clock + $timeshift) / $time_range;
 					$y = $this->canvas_y + $this->canvas_height * ($max_value - $point) / $value_diff;
+
+					if (!$in_range) {
+						$y = ($point > $max_value) ? max($y_min, $y) : min($y_max, $y);
+					}
+
 					$paths[$path_num][] = [$x, ceil($y), convert_units([
 						'value' => $point,
 						'units' => $metric['units']
