@@ -295,18 +295,22 @@ jQuery(function ($){
 		was_dragged = false,
 		prevent_click = false;
 
-	$(document).on('mousedown', 'img', selectionHandlerDragStart)
+	$(document)
+		.on('mousedown', 'img', selectionHandlerDragStart)
 		.on('dblclick', 'img', function(e) {
-			$.publish('timeselector.zoomout', {
-				from: element.from.val(),
-				to: element.to.val()
-			});
+			if (typeof $(e.target).data('zbx_sbox') !== 'undefined') {
+				$.publish('timeselector.zoomout', {
+					from: element.from.val(),
+					to: element.to.val()
+				});
 
-			return cancelEvent(e);
+				return cancelEvent(e);
+			}
 		})
 		.on('click', 'a', function(e) {
 			// Prevent click on graph image parent <a/> element when clicked inside graph selectable area.
-			if ($(e.target).is('img') && prevent_click && $(this).hasClass('dashbrd-widget-graph-link')) {
+			if ($(e.target).is('img') && typeof $(e.target).data('zbx_sbox') !== 'undefined' && prevent_click
+					&& $(this).hasClass('dashbrd-widget-graph-link')) {
 				return cancelEvent(e);
 			}
 		});
